package rh213424;

import org.graphstream.algorithm.Toolkit;
import org.graphstream.graph.BreadthFirstIterator;
import org.graphstream.graph.Graph;
import org.graphstream.graph.Node;
import org.graphstream.graph.implementations.DefaultGraph;
import org.graphstream.stream.file.FileSource;
import org.graphstream.stream.file.FileSourceEdge;
import org.graphstream.stream.file.FileSourceFactory;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.*;

import static org.graphstream.algorithm.Toolkit.*;

public class App {

    public static void main(String ... args) throws IOException {
        String filePath = "./resources/com-dblp.ungraph.txt";
        Graph g = new DefaultGraph("g");
        FileSource fs = new FileSourceEdge();
        fs.addSink(g);
        System.setProperty("org.graphstream.ui", "swing");
        //g.display();

        try {
            fs.readAll(filePath);
            //Affichage des données sur le réseau
            int nbrNoeuds = g.getNodeCount();
            System.out.println("Le nombre des noeuds du graphe "+g.getNodeCount());
            System.out.println("Le nombre des liens du graphe "+g.getEdgeCount());
            System.out.println("Le degré moyen est : "+averageDegree(g));
            System.out.println("Le coefficient de clustering est : "+averageClusteringCoefficient(g));
            System.out.println("Le réseau est il connexe ? "+isConnected(g));

            System.out.println("La distribution des degrés ");
            int[] dd = Toolkit.degreeDistribution(g);
            StringBuilder r = new StringBuilder();
            for (int k = 0; k < dd.length; k++) {
                if (dd[k] != 0) {
                    System.out.printf(Locale.US, "%6d%20.8f%n", k, (double)dd[k] / g.getNodeCount());
                    r.append(k).append(" ").append((double) dd[k] / g.getNodeCount()).append(System.getProperty("line.separator"));
                }
            }
            //fichier de données de sitribution des degrés
            File file = new File("./resources/distributionDegres.dat");
            if (!file.exists()) {
                file.createNewFile();
            }
            FileWriter fw = new FileWriter(file.getAbsoluteFile());
            BufferedWriter bw = new BufferedWriter(fw);
            bw.write(r.toString());
            bw.close();
            //construction de l'échantillon
            double sommeDistances = 0;
            int nbr=0;
            //parcours en largeur
            for(int i = 0 ; i < 1000 ; i++){
                Node depart = randomNode(g);
                BreadthFirstIterator it = new BreadthFirstIterator(depart);
                while(it.hasNext()){
                    Node next = it.next();
                    sommeDistances += it.getDepthOf(next);
                    nbr++;
                }
            }
            System.out.println("la distance moyenne est :"+(sommeDistances/nbr));
        } catch (IOException e) {
            e.printStackTrace();
        }

        fs.removeSink(g);
    }
}
//gnuplot nonFichier.gnu